==> jc-1.4.0.tar.gz: soot/jimple/parser/node/X2PDeclaration.h <==
// public final class soot.jimple.parser.node.X2PDeclaration

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class c16109166091577b soot_jimple_parser_node_X2PDeclaration
// @dep_class b78912b2d6bd2ea8 soot_jimple_parser_node_XPDeclaration

// header file dependencies
// @dep_header soot_jimple_parser_node_XPDeclaration

#include "soot/jimple/parser/node/XPDeclaration.h"

#ifndef _JC_soot_jimple_parser_node_X2PDeclaration_H_
#define _JC_soot_jimple_parser_node_X2PDeclaration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PDeclaration$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PDeclaration$sub_refs	_jc_soot_jimple_parser_node_X2PDeclaration$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PDeclaration$sub_nonrefs	_jc_soot_jimple_parser_node_X2PDeclaration$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PDeclaration$refs	_jc_soot_jimple_parser_node_X2PDeclaration$refs;
typedef struct _jc_soot_jimple_parser_node_X2PDeclaration$nonrefs	_jc_soot_jimple_parser_node_X2PDeclaration$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PDeclaration$object	_jc_soot_jimple_parser_node_X2PDeclaration$object;

typedef const struct _jc_soot_jimple_parser_node_X2PDeclaration$vmethods	_jc_soot_jimple_parser_node_X2PDeclaration$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PDeclaration$vtable	_jc_soot_jimple_parser_node_X2PDeclaration$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PDeclaration$vtype	_jc_soot_jimple_parser_node_X2PDeclaration$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *);
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$_init$8b8151c371068221(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_PDeclaration$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PDeclaration$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *);
extern struct _jc_soot_jimple_parser_node_PDeclaration$object *_jc_soot_jimple_parser_node_X2PDeclaration$method$getPDeclaration$caac28ef1e904575(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *);
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$setPDeclaration$ee0ffcea0b1c5ed3(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_PDeclaration$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PDeclaration$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$getPDeclaration$caac28ef1e904575;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$setPDeclaration$ee0ffcea0b1c5ed3;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PDeclaration$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *);
	struct _jc_soot_jimple_parser_node_PDeclaration$object	*(*getPDeclaration$caac28ef1e904575)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPDeclaration$ee0ffcea0b1c5ed3)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_PDeclaration$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PDeclaration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPDeclaration$vmethods	soot_jimple_parser_node_XPDeclaration;
	_jc_soot_jimple_parser_node_X2PDeclaration$vmethods	soot_jimple_parser_node_X2PDeclaration;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PDeclaration$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PDeclaration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PDeclaration$sub_refs {
	struct _jc_soot_jimple_parser_node_PDeclaration$object	*__5fpDeclaration__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PDeclaration$refs {
    _jc_soot_jimple_parser_node_X2PDeclaration$sub_refs	soot_jimple_parser_node_X2PDeclaration;
    _jc_soot_jimple_parser_node_XPDeclaration$sub_refs	soot_jimple_parser_node_XPDeclaration;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PDeclaration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PDeclaration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPDeclaration$sub_nonrefs	soot_jimple_parser_node_XPDeclaration;
    _jc_soot_jimple_parser_node_X2PDeclaration$sub_nonrefs	soot_jimple_parser_node_X2PDeclaration;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PDeclaration$object {
	_jc_soot_jimple_parser_node_X2PDeclaration$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PDeclaration$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PDeclaration$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PDeclaration$vtype _jc_soot_jimple_parser_node_X2PDeclaration$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PDeclaration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PDeclaration$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PDeclaration_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/X2PDeclaration.h <==
// public final class soot.jimple.parser.node.X2PDeclaration

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class c16109166091577b soot_jimple_parser_node_X2PDeclaration
// @dep_class b78912b2d6bd2ea8 soot_jimple_parser_node_XPDeclaration

// header file dependencies
// @dep_header soot_jimple_parser_node_XPDeclaration

#include "soot/jimple/parser/node/XPDeclaration.h"

#ifndef _JC_soot_jimple_parser_node_X2PDeclaration_H_
#define _JC_soot_jimple_parser_node_X2PDeclaration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PDeclaration$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PDeclaration$sub_refs	_jc_soot_jimple_parser_node_X2PDeclaration$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PDeclaration$sub_nonrefs	_jc_soot_jimple_parser_node_X2PDeclaration$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PDeclaration$refs	_jc_soot_jimple_parser_node_X2PDeclaration$refs;
typedef struct _jc_soot_jimple_parser_node_X2PDeclaration$nonrefs	_jc_soot_jimple_parser_node_X2PDeclaration$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PDeclaration$object	_jc_soot_jimple_parser_node_X2PDeclaration$object;

typedef const struct _jc_soot_jimple_parser_node_X2PDeclaration$vmethods	_jc_soot_jimple_parser_node_X2PDeclaration$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PDeclaration$vtable	_jc_soot_jimple_parser_node_X2PDeclaration$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PDeclaration$vtype	_jc_soot_jimple_parser_node_X2PDeclaration$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$_init$8b8151c371068221(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_PDeclaration$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PDeclaration$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PDeclaration$object *_jc_soot_jimple_parser_node_X2PDeclaration$method$getPDeclaration$caac28ef1e904575(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PDeclaration$method$setPDeclaration$ee0ffcea0b1c5ed3(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_PDeclaration$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PDeclaration$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$getPDeclaration$caac28ef1e904575;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$setPDeclaration$ee0ffcea0b1c5ed3;
extern _jc_method _jc_soot_jimple_parser_node_X2PDeclaration$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PDeclaration$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PDeclaration$object	*(*getPDeclaration$caac28ef1e904575)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPDeclaration$ee0ffcea0b1c5ed3)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *, struct _jc_soot_jimple_parser_node_PDeclaration$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PDeclaration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PDeclaration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPDeclaration$vmethods	soot_jimple_parser_node_XPDeclaration;
	_jc_soot_jimple_parser_node_X2PDeclaration$vmethods	soot_jimple_parser_node_X2PDeclaration;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PDeclaration$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PDeclaration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PDeclaration$sub_refs {
	struct _jc_soot_jimple_parser_node_PDeclaration$object	*__5fpDeclaration__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PDeclaration$refs {
    _jc_soot_jimple_parser_node_X2PDeclaration$sub_refs	soot_jimple_parser_node_X2PDeclaration;
    _jc_soot_jimple_parser_node_XPDeclaration$sub_refs	soot_jimple_parser_node_XPDeclaration;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PDeclaration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PDeclaration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPDeclaration$sub_nonrefs	soot_jimple_parser_node_XPDeclaration;
    _jc_soot_jimple_parser_node_X2PDeclaration$sub_nonrefs	soot_jimple_parser_node_X2PDeclaration;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PDeclaration$object {
	_jc_soot_jimple_parser_node_X2PDeclaration$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PDeclaration$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PDeclaration$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PDeclaration$vtype _jc_soot_jimple_parser_node_X2PDeclaration$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PDeclaration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PDeclaration$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PDeclaration_H_ */
